@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Licensed to the Software Freedom Conservancy (SFC) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -17,19 +19,23 @@
 
 require 'selenium/webdriver/ie/driver'
 require 'selenium/webdriver/ie/options'
-require 'selenium/webdriver/ie/service'
 
 module Selenium
   module WebDriver
     module IE
       def self.driver_path=(path)
-        Platform.assert_executable path
-        @driver_path = path
+        WebDriver.logger.deprecate 'Selenium::WebDriver::IE#driver_path=',
+                                   'Selenium::WebDriver::IE::Service#driver_path='
+        Selenium::WebDriver::IE::Service.driver_path = path
       end
 
       def self.driver_path
-        @driver_path ||= nil
+        WebDriver.logger.deprecate 'Selenium::WebDriver::IE#driver_path',
+                                   'Selenium::WebDriver::IE::Service#driver_path'
+        Selenium::WebDriver::IE::Service.driver_path
       end
     end # IE
   end # WebDriver
 end # Selenium
+
+require 'selenium/webdriver/ie/service'
