@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Licensed to the Software Freedom Conservancy (SFC) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -116,6 +118,20 @@ module Selenium
                               'return source;')
           end
 
+          #
+          # Create a new top-level browsing context
+          # https://w3c.github.io/webdriver/#new-window
+          # @param type [String] Supports two values: 'tab' and 'window'.
+          #  Use 'tab' if you'd like the new window to share an OS-level window
+          #  with the current browsing context.
+          #  Use 'window' otherwise
+          # @return [Hash] Containing 'handle' with the value of the window handle
+          #  and 'type' with the value of the created window type
+          #
+          def new_window(type)
+            execute :new_window, {}, {type: type}
+          end
+
           def switch_to_window(name)
             execute :switch_to_window, {}, {handle: name}
           end
@@ -162,16 +178,14 @@ module Selenium
           end
 
           def resize_window(width, height, handle = :current)
-            unless handle == :current
-              raise Error::WebDriverError, 'Switch to desired window before changing its size'
-            end
+            raise Error::WebDriverError, 'Switch to desired window before changing its size' unless handle == :current
+
             set_window_rect(width: width, height: height)
           end
 
           def window_size(handle = :current)
-            unless handle == :current
-              raise Error::UnsupportedOperationError, 'Switch to desired window before getting its size'
-            end
+            raise Error::UnsupportedOperationError, 'Switch to desired window before getting its size' unless handle == :current
+
             data = execute :get_window_rect
 
             Dimension.new data['width'], data['height']
@@ -182,9 +196,8 @@ module Selenium
           end
 
           def maximize_window(handle = :current)
-            unless handle == :current
-              raise Error::UnsupportedOperationError, 'Switch to desired window before changing its size'
-            end
+            raise Error::UnsupportedOperationError, 'Switch to desired window before changing its size' unless handle == :current
+
             execute :maximize_window
           end
 
@@ -203,7 +216,7 @@ module Selenium
 
           def set_window_rect(x: nil, y: nil, width: nil, height: nil)
             params = {x: x, y: y, width: width, height: height}
-            params.update(params) { |k, v| Integer(v) unless v.nil? }
+            params.update(params) { |_k, v| Integer(v) unless v.nil? }
             execute :set_window_rect, {}, params
           end
 
@@ -302,8 +315,8 @@ module Selenium
           # cookies
           #
 
-          def options
-            @options ||= WebDriver::W3COptions.new(self)
+          def manage
+            @manage ||= WebDriver::W3CManager.new(self)
           end
 
           def add_cookie(cookie)
@@ -459,6 +472,7 @@ module Selenium
           end
 
           def element_attribute(element, name)
+            WebDriver.logger.info "Using script for :getAttribute of #{name}"
             execute_atom :getAttribute, element, name
           end
 
@@ -506,6 +520,7 @@ module Selenium
           end
 
           def element_displayed?(element)
+            WebDriver.logger.info 'Using script for :isDisplayed'
             execute_atom :isDisplayed, element
           end
 
@@ -569,7 +584,7 @@ module Selenium
             [how, what]
           end
 
-          ESCAPE_CSS_REGEXP = /(['"\\#.:;,!?+<>=~*^$|%&@`{}\-\[\]\(\)])/
+          ESCAPE_CSS_REGEXP = /(['"\\#.:;,!?+<>=~*^$|%&@`{}\-\[\]\(\)])/.freeze
           UNICODE_CODE_POINT = 30
 
           # Escapes invalid characters in CSS selector.
